@@ -1,67 +1,67 @@
 set.seed(1234)
-nreps <- 10
+nreps <- 5
 
 # SEPARATE BIAS PARAMETERS
 # 0 confounders
 
-nobias_model <- glm(
-  Y ~ X + U,
-  family = binomial(link = "logit"),
-  data = df_uc_em_sel_source
-)
-or_true <- exp(summary(nobias_model)$coef[2, 1])
+# nobias_model <- glm(
+#   Y ~ X + U,
+#   family = binomial(link = "logit"),
+#   data = df_uc_em_sel_source
+# )
+# or_true <- exp(summary(nobias_model)$coef[2, 1])
 
-u_model <- glm(
-  U ~ X + Y,
-  family = binomial(link = "logit"),
-  data = df_uc_em_sel_source
-)
-x_model <- glm(
-  X ~ Xstar + Y,
-  family = binomial(link = "logit"),
-  data = df_uc_em_sel_source
-)
-s_model <- glm(
-  S ~ Xstar + Y,
-  family = binomial(link = "logit"),
-  data = df_uc_em_sel_source
-)
+# u_model <- glm(
+#   U ~ X + Y,
+#   family = binomial(link = "logit"),
+#   data = df_uc_em_sel_source
+# )
+# x_model <- glm(
+#   X ~ Xstar + Y,
+#   family = binomial(link = "logit"),
+#   data = df_uc_em_sel_source
+# )
+# s_model <- glm(
+#   S ~ Xstar + Y,
+#   family = binomial(link = "logit"),
+#   data = df_uc_em_sel_source
+# )
 
-df_observed <- data_observed(
-  df_uc_em_sel,
-  bias = c("uc", "em", "sel"),
-  exposure = "Xstar",
-  outcome = "Y",
-  confounders = NULL
-)
-list_for_uc_em_sel <- list(
-  u = as.vector(coef(u_model)),
-  x = as.vector(coef(x_model)),
-  s = as.vector(coef(s_model))
-)
-bp_uc_em_sel <- bias_params(coef_list = list_for_uc_em_sel)
+# df_observed <- data_observed(
+#   df_uc_em_sel,
+#   bias = c("uc", "em", "sel"),
+#   exposure = "Xstar",
+#   outcome = "Y",
+#   confounders = NULL
+# )
+# list_for_uc_em_sel <- list(
+#   u = as.vector(coef(u_model)),
+#   x = as.vector(coef(x_model)),
+#   s = as.vector(coef(s_model))
+# )
+# bp_uc_em_sel <- bias_params(coef_list = list_for_uc_em_sel)
 
-single_run <- adjust_uc_em_sel(
-  df_observed,
-  bias_params = bp_uc_em_sel
-)
+# single_run <- multibias_adjust(
+#   df_observed,
+#   bias_params = bp_uc_em_sel
+# )
 
-bs_run <- multibias_adjust(
-  df_observed,
-  bias_params = bp_uc_em_sel,
-  bootstrap = TRUE,
-  bootstrap_reps = nreps
-)
+# bs_run <- multibias_adjust(
+#   df_observed,
+#   bias_params = bp_uc_em_sel,
+#   bootstrap = TRUE,
+#   bootstrap_reps = nreps
+# )
 
-test_that("0 confounders: odds ratio and confidence interval output", {
-  expect_gt(bs_run$estimate, or_true - 0.1)
-  expect_lt(bs_run$estimate, or_true + 0.1)
-  expect_vector(
-    single_run$ci,
-    ptype = double(),
-    size = 2
-  )
-})
+# test_that("0 confounders: odds ratio and confidence interval output", {
+#   expect_gt(bs_run$estimate, or_true - 0.1)
+#   expect_lt(bs_run$estimate, or_true + 0.1)
+#   expect_vector(
+#     single_run$ci,
+#     ptype = double(),
+#     size = 2
+#   )
+# })
 
 # 3 confounders
 
@@ -102,7 +102,7 @@ list_for_uc_em_sel <- list(
 )
 bp_uc_em_sel <- bias_params(coef_list = list_for_uc_em_sel)
 
-single_run <- adjust_uc_em_sel(
+single_run <- multibias_adjust(
   df_observed,
   bias_params = bp_uc_em_sel
 )
@@ -161,7 +161,7 @@ list_for_uc_em_sel <- list(
 )
 bp_uc_em_sel <- bias_params(coef_list = list_for_uc_em_sel)
 
-single_run <- adjust_uc_em_sel(
+single_run <- multibias_adjust(
   df_observed,
   bias_params = bp_uc_em_sel
 )
@@ -218,7 +218,7 @@ list_for_uc_em_sel <- list(
 )
 bp_uc_em_sel <- bias_params(coef_list = list_for_uc_em_sel)
 
-single_run <- adjust_uc_em_sel(
+single_run <- multibias_adjust(
   df_observed,
   bias_params = bp_uc_em_sel
 )
@@ -242,7 +242,7 @@ test_that("3 confounders: odds ratio and confidence interval output", {
 
 # adjust with validation data
 
-or_val <- adjust_uc_em_sel(
+val_run <- multibias_adjust(
   data_observed = data_observed(
     df_uc_em_sel,
     bias = c("uc", "em", "sel"),
@@ -257,10 +257,12 @@ or_val <- adjust_uc_em_sel(
     confounders = c("C1", "C2", "C3", "U"),
     misclassified_exposure = "Xstar",
     selection = "S"
-  )
+  ),
+  bootstrap = TRUE,
+  bootstrap_reps = nreps
 )
 
 test_that("adjust_uc_em_sel, validation data", {
-  expect_gt(or_val$estimate, or_true - 0.1)
-  expect_lt(or_val$estimate, or_true + 0.1)
+  expect_gt(val_run$estimate, or_true - 0.1)
+  expect_lt(val_run$estimate, or_true + 0.1)
 })
